# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import feincms.translations


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Person',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title_prefix', models.CharField(help_text='Nap\u0159\xedklad: Ing.', max_length=127, verbose_name='Titul p\u0159ed jm\xe9nem', blank=True)),
                ('first_name', models.CharField(help_text='Nap\u0159\xedklad: Martin', max_length=127, verbose_name='Jm\xe9no')),
                ('last_name', models.CharField(help_text='Nap\u0159\xedklad: Kocourek', max_length=127, verbose_name='P\u0159\xedjmen\xed')),
                ('title_suffix', models.CharField(help_text='Nap\u0159\xedklad: PhD.', max_length=127, verbose_name='Titul za jm\xe9nem', blank=True)),
                ('nick_name', models.SlugField(help_text='Nap\u0159\xedklad: fanda', max_length=127, verbose_name='Nickname')),
                ('email', models.EmailField(help_text='P\u0159.: martin.kocourek@contractis.cz', max_length=75, verbose_name='E-mail', blank=True)),
                ('photo', models.ImageField(help_text='Pou\u017eijte obr\xe1zky ve form\xe1tu JPEG, GIF nebo PNG. Obr\xe1zky se automaticky zmen\u0161\xed na po\u017eadovan\xfd rozm\u011br.', upload_to=b'team', verbose_name='Fotografie', blank=True)),
                ('category', models.CharField(default=b'1', help_text='Pro \u010dlen\u011bn\xed na str\xe1nce.', max_length=127, verbose_name='Kategorie', choices=[(b'0', '0'), (b'1', '1')])),
                ('sort_order', models.PositiveIntegerField(help_text='Nepovinn\xfd \xfadaj pro mo\u017enost vlastn\xedho \u0159azen\xed. Pokud m\xe1 v\xedce zam\u011bstnanc\u016f stejn\xe9 po\u0159adov\xe9 \u010d\xedslo, \u0159ad\xed se zam\u011bstnanci abecedn\u011b dle p\u0159\xedjmen\xed.', null=True, verbose_name='Po\u0159ad\xed', blank=True)),
                ('active', models.BooleanField(default=True, help_text='Neaktivn\xed karty zam\u011bstnance se nezobraz\xed na str\xe1nce.', verbose_name='Je aktivn\xed?')),
            ],
            options={
                'ordering': ['sort_order', 'last_name'],
                'verbose_name': 'Team member',
                'verbose_name_plural': 'Team members',
            },
            bases=(models.Model, feincms.translations.TranslatedObjectMixin),
        ),
        migrations.CreateModel(
            name='PersonContact',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('engine', models.CharField(blank=True, max_length=255, verbose_name='Type', choices=[(b'facebook', 'Facebook'), (b'linkedin', 'LinkedIn'), (b'twitter', 'Twitter'), (b'github', 'Github')])),
                ('url', models.URLField(verbose_name='url', blank=True)),
                ('person', models.ForeignKey(related_name='contacts', verbose_name='person', to='team.Person')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='PersonTranslation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('language_code', models.CharField(default=b'en', max_length=10, verbose_name='language', choices=[(b'en', b'EN'), (b'cs', b'CS')])),
                ('position', models.CharField(max_length=250, verbose_name='position', blank=True)),
                ('summary', models.TextField(null=True, verbose_name='top text', blank=True)),
                ('description', models.TextField(null=True, verbose_name='bottom text', blank=True)),
                ('parent', models.ForeignKey(related_name='translations', to='team.Person')),
            ],
            options={
                'verbose_name': 'text',
                'verbose_name_plural': 'texts',
            },
            bases=(models.Model,),
        ),
    ]



from django.conf.urls import *

urlpatterns = patterns('team.views',
                       (r'^$', 'person_list', {}, 'project_team_list'),
                       (r'^(?P<person_nick_name>\w+)/$',
                        'person_detail', {}, 'project_team_detail'),
                       )



# -*- coding: UTF-8 -*-

from django.shortcuts import render_to_response
from django.template import RequestContext
from feincms.views.decorators import standalone
from models import Person


def person_list(request):
    object_list = Person.objects.filter(active__exact=True).order_by('sort_order')
    context = RequestContext(request, {
        'object_list': object_list,
    })
    return render_to_response('team/person_list.html', {}, context_instance=context)


@standalone
def person_detail(request, person_nick_name):
    object = Person.objects.get(nick_name=person_nick_name)
    context = RequestContext(request, {
        'object': object,
    })
    return render_to_response('team/person_detail.html', {}, context_instance=context)



# -#- coding: utf-8 -#-

from django.utils.translation import ugettext_lazy as _

from leonardo.module.web.models import Widget

from team.models import Person


class TeamWidget(Widget):

    def get_team(self):
        return Person.objects.all()

    class Meta:
        abstract = True
        verbose_name = _("team")
        verbose_name_plural = _("team")



# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _

from feincms.translations import TranslatedObjectMixin, Translation, TranslatedObjectManager

PERSON_CATEGORIES = (
    ('0', _("0")),
    ('1', _("1")),
)


class Person(models.Model, TranslatedObjectMixin):

    """
    Model of a team member.
    """
    title_prefix = models.CharField(
        max_length=127, blank=True, verbose_name=u"Titul před jménem", help_text=u"Například: Ing.")
    first_name = models.CharField(
        max_length=127, verbose_name=u"Jméno", help_text=u"Například: Martin")
    last_name = models.CharField(
        max_length=127, verbose_name=u"Příjmení", help_text=u"Například: Kocourek")
    title_suffix = models.CharField(
        max_length=127, blank=True, verbose_name=u"Titul za jménem", help_text=u"Například: PhD.")
    nick_name = models.SlugField(
        max_length=127, verbose_name=u"Nickname", help_text=u"Například: fanda")

    email = models.EmailField(
        blank=True, verbose_name=u"E-mail", help_text=u"Př.: martin.kocourek@contractis.cz")
    photo = models.ImageField(upload_to="team", blank=True, verbose_name=u"Fotografie",
                              help_text=u"Použijte obrázky ve formátu JPEG, GIF nebo PNG. Obrázky se automaticky zmenší na požadovaný rozměr.")
    category = models.CharField(max_length=127, verbose_name=u"Kategorie",
                                help_text=u"Pro členění na stránce.", default="1", choices=PERSON_CATEGORIES)
    sort_order = models.PositiveIntegerField(verbose_name=u"Pořadí", blank=True, null=True,
                                             help_text=u"Nepovinný údaj pro možnost vlastního řazení. Pokud má více zaměstnanců stejné pořadové číslo, řadí se zaměstnanci abecedně dle příjmení.")
    active = models.BooleanField(default=True, verbose_name=u"Je aktivní?",
                                 help_text=u"Neaktivní karty zaměstnance se nezobrazí na stránce.")

    objects = TranslatedObjectManager()

    class Meta:
        ordering = ['sort_order', 'last_name', ]
        verbose_name = _("Team member")
        verbose_name_plural = _("Team members")

    def full_name(self):
        return u'%s %s %s %s' % (self.title_prefix, self.last_name, self.first_name, self.title_suffix)

    @property
    def display(self):
        return u'%s %s' % (self.first_name, self.last_name)

    def get_absolute_url(self):
        from leonardo.module.web.widget.application.reverse import app_reverse
        return app_reverse(
            'project_team_detail',
            'team.apps.team',
            kwargs={
                'person_nick_name': self.nick_name,
            })

    def __unicode__(self):
        return u'%s %s' % (self.first_name, self.last_name)
        # return u'%s, %s' % (self.last_name, self.first_name)

CONTACT_CHOICES = (
    ("facebook", u"Facebook"),
    ("linkedin", u"LinkedIn"),
    ("twitter", u"Twitter"),
    ("github", u"Github"),
)


class PersonContact(models.Model):

    person = models.ForeignKey("Person", verbose_name=u"person", related_name="contacts")
    engine = models.CharField(
        u"Type", choices=CONTACT_CHOICES, max_length=255, blank=True)
    url = models.URLField(u"url", blank=True)

    def __unicode__(self):
        return self.person.__unicode__()


class PersonTranslation(Translation(Person)):

    """
    Translations for person.
    """
    position = models.CharField(_('position'), max_length=250, blank=True)
    summary = models.TextField(_('top text'), blank=True, null=True)
    description = models.TextField(_('bottom text'), blank=True, null=True)

    class Meta:
        verbose_name = _('text')
        verbose_name_plural = _('texts')

    def __unicode__(self):
        return self.position



# -*- coding: utf-8 -*-

from django.conf import settings
from django import forms
from django.forms.models import modelformset_factory
from django.contrib import admin
from django.utils.translation import ugettext as _

from sorl.thumbnail import get_thumbnail

from .models import Person, PersonTranslation, PersonContact


class PersonTranslation_Inline(admin.StackedInline):
    model = PersonTranslation
    max_num = len(settings.LANGUAGES)


def thumb(object):
    if object.photo:
        thumb = get_thumbnail(object.photo, '50x50', format='PNG')
        return "<img src='%s' alt='' />" % thumb.url
    else:
        return 'N/A'
thumb.short_description = _('preview')
thumb.allow_tags = True


class PersonContact_Inline(admin.StackedInline):
    model = PersonContact


class PersonAdmin(admin.ModelAdmin):
    list_display = ['full_name', 'category', thumb, 'sort_order', 'active', ]
    list_filter = ('active', 'category')
    list_editable = ('sort_order', 'active',)
    inlines = [PersonTranslation_Inline, PersonContact_Inline]

admin.site.register(Person, PersonAdmin)




from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _

from .widget import *

default_app_config = 'team.Config'


class Default(object):

    optgroup = 'Team'

    apps = [
        'team',
    ]

    widgets = [
        TeamWidget,
    ]

    plugins = [
        ('team.apps.team', _('Team members')),
    ]


class Config(AppConfig, Default):
    name = 'team'
    verbose_name = _("Team")

default = Default()
